#
# spec file for package janus-gateway
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1320
%bcond_without janus_postprocessing
%endif

Name:           janus-gateway
Version:        1.1.4
Release:        1.1
License:        GPL-3.0-or-later
Summary:        Janus WebRTC Gateway
URL:            https://github.com/meetecho/janus-gateway
Group:          Productivity/Networking/Other
Source:         %{name}-%{version}.tar.xz
Source1:        janus.service
Source2:        %{name}.sysusers
Source100:      %{name}-rpmlintrc
# for run autogen.sh
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
# basic dependencies
BuildRequires:  pkg-config
BuildRequires:  curl-devel
BuildRequires:  gengetopt
BuildRequires:  libconfig-devel
BuildRequires:  sofia-sip-devel
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(ini_config)
BuildRequires:  pkgconfig(jansson) >= 2.5
BuildRequires:  pkgconfig(libmicrohttpd) >= 0.9.59
BuildRequires:  pkgconfig(libpcap)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(nice) >= 0.1.18
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openssl) >= 1.0.1e
BuildRequires:  pkgconfig(opus)
%if %{with janus_postprocessing}
BuildRequires:  libavcodec-devel
BuildRequires:  libavformat-devel
BuildRequires:  libavutil-devel
%endif
# data channel support
BuildRequires:  usrsctp-devel
# websockets support
BuildRequires:  libwebsockets-devel >= 4.0.0
# MQTT support
BuildRequires:  libpaho-mqtt-devel
Requires(pre):  shadow
BuildRequires:  pkgconfig(systemd)

%{?systemd_ordering}
%{sysusers_requires}

%description
Janus is a general-purpose WebRTC gateway designed and developed
by Meetecho.

%package devel
Requires:       %{name} = %{version}
Summary:        Development files for Janus Gateway plugins
Group:          Development/Libraries/C and C++

%description devel
Janus is a general-purpose WebRTC gateway designed and developed
by Meetecho.

This package holds the file needed to compile plugins for Janus Gateway.

%prep
%autosetup -p1

%build
%sysusers_generate_pre %{SOURCE2} %{name}
./autogen.sh
%configure \
  --disable-static \
  --enable-libsrtp2 \
  --enable-plugin-lua \
  %if %{with janus_postprocessing}
  --enable-post-processing \
  %endif
  --disable-rabbitmq \
  --disable-docs
%make_build

%install
%make_install
rm -f %{buildroot}%{_libdir}/janus/plugins/*.la
make configs DESTDIR=%{buildroot}
#
install -D -d -m 755 %{buildroot}%{_sbindir}
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/janus.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcjanus
#
pushd %{buildroot}%{_sysconfdir}/janus/
rm -rv *.jcfg.sample
chmod -R o= .
popd
rm -rv %{buildroot}%{_datadir}/doc/%{name}
rm -rv %{buildroot}%{_datadir}/janus/streams/test_gstreamer*.sh
#
install -D -d -m 0750 %{buildroot}%{_sharedstatedir}/janus/

%pre -f %{name}.pre
%service_add_pre janus.service

%post
%service_add_post janus.service

%preun
%service_del_preun janus.service

%postun
%service_del_postun janus.service

%files
%doc README.md
%license COPYING
%config(noreplace) %attr(-,root,janus) %{_sysconfdir}/janus/
%{_sbindir}/rcjanus
%{_bindir}/janus
%{_bindir}/janus-cfgconv
%{_mandir}/man1/janus.1*
%{_mandir}/man1/janus-cfgconv.1*
%if %{with janus_postprocessing}
%{_bindir}/janus-pp-rec
%{_bindir}/mjr2pcap
%{_bindir}/pcap2mjr
%{_mandir}/man1/janus-pp-rec.1*
%{_mandir}/man1/mjr2pcap.1*
%{_mandir}/man1/pcap2mjr.1.gz
%endif
%{_libdir}/janus/
%{_datadir}/janus/
%{_unitdir}/janus.service
%dir %attr(750,janus,janus) %{_sharedstatedir}/janus/

%files devel
%{_includedir}/janus/

%changelog
* Tue Oct 10 2023 chris@computersalat.de
- Update to [v1.1.4] - 2023-05-19
  * Moved discussions from Google Group to Discourse
  * Fixed typo in command line argument validation
  * Refactored RTP forwarder internals as a core feature [PR-3155]
  * Refactored SVC processing as a core feature, and removed deprecated VP9/SVC demo [PR-3174]
  * Don't create IPv6 sockets if IPv6 is completely disabled [PR-3179]
  * Fixed some VideoRoom race conditions [PR-3167]
  * Added simulcast/SVC params to switch in VideoRoom (thanks @brave44!) [PR-3197]
  * Add support for receiving offers in Streaming plugin (for WHEP) [PR-3199]
  * Add newline for SIP headers that are overflown in length (thanks @zayim!) [PR-3184]
  * Save SIP reason state on multiple callbacks (thanks @kenangenjac!) [PR-3210]
  * Avoid parsing whitespace as invalid JSON when receiving WebSocket messages (thanks @htrendev!) [PR-3208]
  * Remove old tracks before adding/replacing new ones in janus.js [PR-3203]
  * Tweaks to some janus.js internals (thanks @i8-pi!) [PR-3211]
  * Fixed some typos and added some tweaks to Admin API demo
  * Refactored npm version of janus.js
  * Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
- update _service, _servicedata file
- fix License to GPL-3.0-or-later
- add janus-gateway.sysusers for group/user creation
- Update dependencies
  * build with libpcap
  * --enable-plugin-lua
  * --enable-librtp2 (swith to libsrtp2)
* Wed Dec  7 2022 michael@stroeder.com
- Update to version 1.1.1:
  * Added timing info on ICE starting and gathering done to Admin API
  * Fixed rare crash when generating SDP to send [Issue-3081]
  * Fixed rare crash when checking payload types (thanks @zevarito!) [PR-3086]
  * Fixed double a=ssrc attribute in SDP for inactive m-line
  * Replaced non-portable strcasestr() with strncasecmp() (thanks @iskraman!) [PR-3076]
  * Fixed parameters not being URL-encoded when using TURN REST API [Issue-3112]
  * Fixed renegotiation sent to VideoRoom subscribers when a room is destroyed [Issue-3083]
  * Added option to prevent automatic SDP offer updates to VideoRoom subscribers when a publisher leaves
  * Fixed "send" property not being automatically reset to "true" in the VideoRoom for new subscriptions
  * Fixed small memory leak in AudioBridge (thanks @RSATom!) [PR-3088]
  * Minor fixes to the Streaming plugin
  * Enforced media direction policies when SIP call is on hold PR-3087]
  * Added code to send PLI to SIP peer when recording [PR-3093]
  * Fixed renegotiations in VideoCall not updating session properties
  * Other smaller fixes and improvements
* Tue Oct  4 2022 michael@stroeder.com
- Update to version 1.1.0:
  * Added versioning to .so files [PR-3075]
  * Allow plugins to specify msid in SDPs [PR-2998]
  * Fixed broken RTCP timestamp on 32bit architectures [Issue-3045]
  * Fixed problems compiling against recent versions of libwebsockets [Issue-3039]
  * Updated deprecated DTLS functions to OpenSSL v3.0 PR-3048]
  * Switched to SHA256 for signing self signed DTLS certificates (thanks @tgabi333!) [PR-3069]
  * Started using strnlen to optimize performance of some strlen calls (thanks @tmatth!) [PR-3059]
  * Added checks to avoid RTX payload type collisions [PR-3080]
  * Added new APIs for cascading VideoRoom publishers [PR-3014]
  * Fixed deadlock when using legacy switch in VideoRoom [Issue-3066]
  * Fixed disabled property not being advertized to subscribers when VideoRoom publishers removed tracks
  * Fixed occasional deadlock when using G.711 in the AudioBridge [Issue-3062]
  * Added new way of capturing devices/tracks in janus.js [PR-3003]
  * Removed call to .stop() for remote tracks in demos [PR-3056]
  * Fixed missing message/info/transfer buttons in SIP demo page
  * Fixed postprocessing compilation issue on older FFmpeg versions [PR-3064]
  * Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
* Mon Aug  1 2022 michael@stroeder.com
- Update to version 1.0.4:
  * Fixed problem with duplicate ptypes when codecs are added in renegotiations
  * Added codec info to event handlers stats
  * Allow offers to include other roles besides 'actpass' for DTLS [PR-3020]
  * Fixed rare race conditions when attempting to relay packets sent by plugins [PR-3010]
  * Fixed unprotected access to medium instances in janus_plugin_handle_sdp
  * Set appropriate channel type when sending DATA_CHANNEL_OPEN_REQUEST message (thanks @ktyu!) [PR-3018]
  * Fixed rare race condition when handling incoming RTCP feedback in VideoRoom
  * Fixed memory leak in VideoRoom when using rid-based simulcast (thanks @OxleyS!) [PR-2995]
  * Fixed IPv6 always enabled for VideoRoom RTP forwarders [Issue-3011]
  * Start recording VideoRoom publisher on PeerConnection establishment, if needed (thanks @adnanel!) [PR-3013]
  * Added an optional ID in subscribe requests to match with subscription events (thanks @JanFellner!) [PR-3027]
  * Make Streaming plugin use SDP utils, and codecs instead of rtpmaps [PR-2994]
  * Check response codes of RTSP requests in Streaming plugin [Issue-3015]
  * Fixed small memory leak in SIP plugin [Issue-3032]
  * Fixed broken simulcast support in Lua and Duktape plugins
  * Don't use .clone() on tracks to render them in demos [PR-3009]
  * Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
* Mon Jun 20 2022 michael@stroeder.com
- Update to version 1.0.3:
  * Keep track of RTP extensions when storing packets for retransmission [PR-2981]
  * Fixed negotiation of RTP extensions when direction is involved
  * Fixed broken VP8 payload descriptor parsing when 7-bit PictureID are used
  * Support for batched configure requests in VideoRoom [PR-2986]
  * Added missing info to VideoRoom publisher's info own event [Issue-2988]
  * Fixed memory leaks in when upgrading old-style Videoroom requests (thanks @OxleyS!) [PR-3002]
  * Fixed memory leak in VideoRoom when updating subscriptions with no changes
  * Added 'kick_all' requests and possibility to remove PIN code to both
    Audiobridge and Streaming plugins (thanks @mikaelnousiainen!) [PR-2978]
  * Added support for notifications in the Streaming plugin when metadata
    for a mountpoint is changed (thanks @amoizard!) [PR-3000]
  * Fixed missing checks on auth challenges in SIP plugin
  * Fixed missing Contact header in SUBSCRIBE requests in SIP plugin [PR-2973]
  * Fixed segfault in SIP plugin when freeing a session with a
    subscription still active [PR-2974]
  * Add new shared JavaScript file for settings in demos [PR-2991]
  * Other smaller fixes and improvements
* Mon May 23 2022 michael@stroeder.com
- Update to version 1.0.2:
  * Support for dummy publishers in VideoRoom (#2958)
  * Fixed RED parsing not returning blocks when only primary data is available
  * Link to -lresolv explicitly when building websockets transport
  * src/dtls-bio.h: fix build with libressl >= 3.5.0 (#2980)
  * Temporarily increase VideoRoom subscriber reference while we're creating it (see #2953)
  * Fix address size in Streaming plugin RTCP sendto call (see #2976)
  * Make SIP timer T1X64 configurable (#2972)
  * Added custom headers for SIP SUBSCRIBE requests (#2971)
  * Fixed incorrect removal of owner/subscriptions mapping (fixes #2965)
  * Explicitly return list of IDs VideoRoom users are subscribed to for data (fixes #2967)
  * Fixed typo in stereo support in EchoTest plugin
  * Added configurable property to put a cap to task threads (see #2964)
  * Disable IPv6 in WebSockets transport if binding to IPv4 address explicitly (fixes #2969)
  * Abort DTLS handshake if DTLSv1_handle_timeout returns an error
  * Fixed data port not being returned when creating Streaming mountpoints with the legacy API
  * Fixed rtx SSRC incorretly added to SDP when disabled
  * Fixed rtx not being offered on Janus originated connections
  * Better cleanup when closing PeerConnection in multistream VideoRoom demo (see #2942)
* Tue Apr 26 2022 michael@stroeder.com
- Update to version 1.0.1:
  * release v1.0.1
  - Removed gengetopt as a dependency, to use Glib's GOptionEntry instead [PR-2898]
  - Fixed occasional problem of duplicate mid attribute in Janus SDPs [Issue-2917]
  - Fixed receiving=false events not being sent right away for higher simulcast substreams [Issue-2919]
  - Fix highest sequence number not being properly initialized in the RTCP context [Issues-2920]
  - Reset rids when renegotiating SDPs [PR-2931]2931)]
  - Fixed missing PLI when restoring previously paused streams in VideoRoom (thanks @flaviogrossi!) [PR-2922]
  - Fixed deadlock when using the moderate API in the VideoRoom [Issue-2956]
  - Check if IPv6 is disabled to avoid failure when creating forwarder sockets in AudioBridge and VideoRoom [PR-2916]
  - Fixed invalid computation of Streaming mountpoint stream age (thanks @RouquinBlanc!) [PR-2928]
  - Also return reason header protocol and cause if present in BYE in the SIP plugin (thanks @ajsa-terko!) [PR-2935]
  - Fixed segfault in UNIX transport teardown caused by pathnames of different sizes
  - Added new demos on WebAudio and Virtual Backgrounds [PR-2941]
  - Fixed potential race conditions in multistream VideoRoom demo [Issue-2929]
  - Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
  * release v1.0.0
  - Refactored Janus to support multistream PeerConnections [PR-2211]
  - Moved all source files under new 'src' folder to unclutter the repo [PR-2885]
  - Fixed definition of trylock wrapper when using pthreads [Issue-2894]
  - Fixed broken RTP when no extensions are negotiated
  - Added checks when inserting RTP extensions to avoid buffer overflows
  - Added missing support for disabled rid simulcast substreams in SDP [PR-2888]
  - Fixed TWCC feedback when simulcast SSRCs are missing (thanks @OxleyS!) [PR-2908]
  - Added support for playout-delay RTP extension [PR-2895]
  - Fixed partially broken H.264 support when using Firefox in VideoRoom
  - Fixed new VideoRoom rtp_forward API ignoring some properties
  - Fixed deadlock and segfault when stopping Streaming mountpoint recordings [Issue-2902]
  - Fixed RTSP support in Streaming plugin for cameras that expect path-only DESCRIBE requests (thanks @jp-bennett!) [PR-2909]
  - Fixed RTP being relayed incorrectly in Lua and Duktape plugins
  - Added Duktape as optional dependency, instead of embedding the engine code [PR-2886]
  - Fixed crash at startup when not able to connect to RabbitMQ server
  - Improved fuzzing and checks on RTP extensions
  - Removed distinction between simulcast and simulcast2 in janus.js [PR-2887]
  - Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
* Fri Feb 11 2022 michael@stroeder.com
- Update to version 0.11.8:
  * Added initial (and limited) integration of RED audio (#2685)
  * Added support for Two-Byte header RTP extensions (RFC8285) and, partially,
    for the new Depencency Descriptor RTP extension (needed for AV1-SVC) (#2741)
  * Fixed rare race conditions between sending a packet and closing a connection (#2869)
  * Fix last stats before closing PeerConnection not being sent to handlers (#2874)
  * Changed automatic allocation on static loops from round robin to least used (#2878)
  * Added new API to bulk start/stop MJR-based recordings in AudioBridge (#2862)
  * Fixed broken duration in spatial AudioBridge recordings
  * Fixed broken G.711 RTP forwarding in AudioBridge (#2875)
  * Fixed broken recordings in NoSIP plugin
  * Fixed warnings when postprocessing Opus recordings with DTX packets
  * Other smaller fixes and improvements
* Mon Jan 24 2022 michael@stroeder.com
- Update to version 0.11.7:
  * Added faster strlcat variant that uses memccpy for writing SDPs (#2835)
  * Fixed occasional crash when updating WebRTC sessions (#2840)
  * Changed SDP syntax for AV1 from "AV1X" to "AV1" (#2844)
  * Fixed signed_tokens property not being saved to permanent rooms in VideoRoom (#2843)
  * Made record directory changeable via "edit" in both AudioBridge and VideoRoom
  * Added configurable expected loss to AudioBridge to actually send FEC (#2802)
  * Fixed SIP plugin not working when using Sofia SIP >= 1.13 (#2683)
  * Fixed occasional crashes in SIP plugin (#2853)
  * Take note of video orientation extension when recording video in SIP plugin (#2836)
  * Allow 180 besides 183 to have SDP as well (#2849)
  * Fixed post-processor compilation issue with newer versions of FFmpeg (#2833)
  * Added option to print extended info on MJR file as JSON in postprocessor (#2858)
  * Allow pcap2mjr to autodetect SSRC
  * Fixed problems compiling post-processor with older versions of FFmpeg
  * Other smaller fixes and improvements
* Mon Dec 13 2021 michael@stroeder.com
- Update to version 0.11.6:
  * Fixed CVE-2021-4020 (see also boo#1193156):
    Cross-site Scripting (XSS) vulnerability in some of the demos (#2817)
  * Added strlcat helper to detect and report truncations (#2792)
  * Grow buffer as needed when generating SDPs (#2797)
  * Added DTX support to some plugins (#2789)
  * Added option to forcibly quit Janus when getting dlopen errors (#2828)
  * Fixed broken signed tokens in VideoRoom when using UUIDs (#2812)
  * Added option to choose whether signed tokens should be used in the
    VideoRoom when enabled in the core (#2825)
  * Added configurable expected loss to AudioBridge to actually send FEC (#2802)
  * Added MESSAGE authentication and out-of-dialog MESSAGE support to SIP plugin (#2786)
  * Fixed potential race conditions in SIP plugin (#2823)
  * Added basic history support to TextRoom plugin (#2814)
  * Added support for custom datachannel options in janus.js (#2806)
  * Other smaller fixes and improvements
* Mon Oct 18 2021 michael@stroeder.com
- dropped obsolete 0001-include-rand-header-file.patch
- Update to version 0.11.5:
  * Add API to optionally force Janus to use TURN (#2774)
  * Fixed slow path on SDP parsing (#2776)
  * Added event handlers option to send stats for a PeerConnection
    in a single event, rather than per-media (#2785)
  * Fixed occasional deadlocks on malformed requests in VideoRoom (#2780)
  * Fixed AudioBridge plain RTP thread sometimes exiting prematurely
  * Fixed broken upsampling when using G.711 in AudioBridge
  * Add pause/resume recording functionality to Record&Play and SIP plugins (#2724)
  * Fixed broken support for Unix Sockets in WebSockets Admin API (#2787)
  * Added timing info for video rotation when post-processing recordings
  * Added linter checks to janus.js (#2272)
  * Other smaller fixes and improvements
* Thu Sep 23 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * janus.service
* Mon Sep  6 2021 Michael Ströder <michael@stroeder.com>
- added janus-gateway-rpmlintrc
- removed systemd-related conditionals to fix obsolete-suse-version-check
- added 0001-include-rand-header-file.patch
- use %%fdupes macro
- Update to version 0.11.4:
  * Fixed ICE restart issues with recent versions of libnice (#2729)
  * Changed randon number generators to use crypto-safe functions (#2738)
  * Added support for abs-send-time RTP extension (#2721)
  * Added configurable mechanism for manually setting static event loop to use for new handles (#2684)
  * Fixed datachannel protocol not being sent to plugins for incoming messages (#2753)
  * Added ability to specify recordings folder in AudioBridge (#2707)
  * Added support for forwarding groups in AudioBridge (#2653)
  * Fixed missing Contact header in SIP plugin when using Sofia >= 1.13 (#2708)
  * Better SDES-SRTP negotiation in SIP and NoSIP plugins (#2727)
  * Fixed WebSocket transport and event handler lagging 25/30s when shutting down or reconnecting (#2734)
  * Fixed incoming_header_prefixes not working for helper sessions in SIP plugin
  * Fix partial/broken ACL support in TextRoom plugin (#2763)
  * Fixed potential race condition when reclaiming sessions in HTTP transport plugin
  * Fixed WebSocket event handler reconnect mechanism (#2736)
  * Other smaller fixes and improvements
* Tue Jun 15 2021 michael@stroeder.com
- Update to version 0.11.3:
  * Fixed rare crash when detaching handles (#2464)
  * Added option to offer IPv6 link-local candidates as well (#2689)
  * Added spatial audio support to AudioBridge via stereo mixing (#2446)
  * Added support for plain RTP participants to AudioBridge (#2464)
  * Added API to start/stop AudioBridge recordings dynamically
    (thanks @rajneeshksoni!) (#2674)
  * Fixed broken mountpoint switching when using different payload types
    in Streaming plugin (#2692)
  * Fixed occasional deadlock on Streaming plugin mountpoint destroy
    during RTSP reconnects (thanks @lionelnicolas!) (#2700)
  * Added "Expires" support to SUBSCRIBE in SIP plugin
    (thanks @nicolasduteil!) (#2661)
  * Added option to specify Call-ID for SUBSCRIBE dialogs in SIP plugin
    (thanks @nicolasduteil!) (#2664)
  * Fixed broken simulcast support in VideoCall plugin
    (thanks @lucily-star!) (#2671)
  * Implemented RabbitMQ reconnection logic, in both transport and event handler
    (thanks @chriswiggins!) (#2651)
  * Added support for renegotiation of external streams in janus.js
    (thanks @kmeyerhofer!) (#2604)
  * Added support for HEVC/H.265 aggregation packets (AP) to janus-pp-rec
    (thanks @nu774!) (#2662)
  * Refactored janus-pp-rec to cleanup the code, and use libavformat for Opus as well
    (thanks @lu-zero!) (#2665)
  * Added additional target formats for some recorded codecs (#2680)
  * Other smaller fixes and improvements
* Mon May  3 2021 michael@stroeder.com
- Update to version 0.11.2:
  - Added support for relative paths in config files, currently only in
    MQTT event handler (thanks @RSATom!) (#2623)
  - Removed support for now deprecated frame-marking RTP extension
    (#2640)
  - Fixex rare race condition between VideoRoom publisher leaving and
    subscriber hanging up (#2637)
  - Fixed occasional crash when using announcements in AudioBridge
  - Fixed rare crash in Streaming plugin when reconnecting RTSP streams
    (thanks @lucylu-star!) (#2542)
  - Fixed broken switch in Streaming plugin when using helper threads
  - Fixed rare race conditions on socket close in SIP and NoSIP plugins
    (#2599)
  - Added support for out-of-dialog SIP MESSAGE requests (thanks
    @ihusejnovic!) (#2616)
  - Fixed memory leak when using helper threads in Streaming plugin
  - Added support for datachannel label/protocol to Lua and Duktape
    plugins (#2641)
  - Added ability to use WebSockets transport over Unix sockets (thanks
    @mdevaev!) (#2620)
  - Added janus-pp-rec mechanism to correct wrong RTP timestamps in MJR
    recordings (thanks @tbence94!) (#2573)
  - Other smaller fixes and improvements
* Tue Apr  6 2021 michael@stroeder.com
- Update to version 0.11.1:
  * Add new option to configure ICE nomination mode, if libnice is recent enough (#2541)
  * Added support for per-session timeout values (thanks @alg!) (#2577)
  * Added support for compilation on FreeBSD (thanks @jsm222!) (#2508)
  * Fixed occasional auth errors when using both API secret and stored tokens (#2581)
  * Added support for stdout logging to daemon-mode as well (#2591)
  * Fixed odr-violation issue between Lua and Duktape plugins (#2540)
  * Fixed missing simulcast stats in Admin API and Event Handlers when using rid (#2610)
  * Fixed VideoRoom recording not stopped for participants entering after global recording was started (#2550)
  * Fixed 'audiocodec'/'videocodec' being ignored when joining a VideoRoom via 'joinandconfigure'
  * Added content type support to MESSAGE in SIP plugin (#2567)
  * Made RTSP timeouts configurable in Streaming plugin (#2598)
  * Fixed incorrect parsing of backend URL in WebSockets event handler (#2603)
  * Added support for secure connections and lws debugging to WebSockets event handler
  * Fixed occasionally broken AV1 recordings post-processing
  * Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
* Mon Feb  8 2021 michael@stroeder.com
- Update to version 0.10.10:
  * Reduced verbosity of a few LOG_WARN messages at startup
  * Close libnice agent resources asynchronously when hanging up PeerConnections (thanks @fbellet!) [PR-2492]
  * Fixed broken parsing of SDP when trying to match specific codec profiles [PR-2549]
  * Added muting/moderation API to the VideoRoom plugin [PR-2513]
  * Fixed a few race conditions in VideoRoom plugin that could lead to crashes [[PR-2539][#2539)]
  * Send 480 instead of BYE when hanging up calls in early dialog in the SIP plugin (thanks @zayim!) [PR-2521]
  * Added configurable media direction when putting calls on-hold in the SIP plugin [PR-2525]
  * Fixed rare race condition in AudioBridge when using "changeroom" (thanks @JeckLabs!) [[PR-2535][#2535)]
  * Fixed broken API secret management in HTTP long polls (thanks @remvst!) [PR-2524]
  * Report failure if binding to a socket fails in WebSockets transport plugin (thanks @Symbiatch!) [PR-2534]
  * Updated RabbitMQ logic in both transport and event handler (thanks @chriswiggins!) [PR-2430]
  * Fixed segfault in WebSocket event handler when backend was unreachable
  * Added TLS support to MQTT event handler (thanks @RSATom!) [PR-2517]
  * Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
* Wed Dec 23 2020 michael@stroeder.com
- Update to version 0.10.9:
  * Replaced Travis CI with GitHub Actions [[PR-2486](#2486)]
  * Fixed data channel messages potentially getting stuck in case of burst transfers (thanks @afshin2003!) [[PR-2427](#2427)]
  * Fixed simulcast issues when renegotiating PeerConnections [[Issue-2466](#2466)]
  * Added configurable TURN REST API timeout (thanks @evorw!) [[PR-2470](#2470)]
  * Added support for recording of binary data channels [[PR-2481](#2481)]
  * Fixed occasional SRTP errors when pausing and then resuming Streaming plugin handles after a long time
  * Fixed occasional SRTP errors when leaving and joining AudioBridge rooms without a new PeerConnection after a long time
  * Added support for playout of data channels in Record&Play plugin and demo (thanks @ricardo-salgado-tekever!) [[PR-2468](#2468)]
  * Added option to override connections limit in HTTP transport plugin [[PR-2489](#2489)]
  * Added options to enable libmicrohttpd debugging in HTTP transport plugin (thanks @evorw!) [[PR-2471](#2471)]
  * Fixed a few compile and runtime issues in WebSocket event handler
  * Refactored postprocessing management of timestamps to fix some key issues [[PR-2345](#2345)]
  * Fixed postprocessing of audio recordings containing RTP silence suppression packets [[PR-2467](#2467)]
  * Other smaller fixes and improvements (thanks to all who contributed pull requests and reported issues!)
* Tue Dec 22 2020 Jan Engelhardt <jengelh@inai.de>
- Do not hard-require systemd. Drop redundant wording from
  description. Drop %%defattr.
* Mon Dec 21 2020 Michael Ströder <michael@stroeder.com>
- Initial packaging of 0.10.8 for Factory
